@@ -1,12 +1,21 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+from composer import algorithms as algorithms
+from composer import callbacks as callbacks
+from composer import datasets as datasets
+from composer import functional as functional
+from composer import loggers as loggers
+from composer import models as models
+from composer import optim as optim
+from composer import profiler as profiler
+from composer import trainer as trainer
+from composer import utils as utils
 from composer.core import Algorithm as Algorithm
 from composer.core import Callback as Callback
 from composer.core import DataSpec as DataSpec
 from composer.core import Engine as Engine
 from composer.core import Evaluator as Evaluator
 from composer.core import Event as Event
-from composer.core import Logger as Logger
 from composer.core import State as State
 from composer.core import Time as Time
 from composer.core import Timer as Timer
@@ -15,4 +24,4 @@ from composer.core import types as types
 from composer.models import ComposerModel as ComposerModel
 from composer.trainer import Trainer as Trainer
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
