@@ -4,14 +4,17 @@ from __future__ import annotations
 
 import functools
 import logging
-from typing import Optional
+import warnings
+from typing import Optional, Sequence, Union
 
 import numpy as np
 import torch
+from torch.optim import Optimizer
 
 from composer.algorithms.blurpool.blurpool_layers import BlurConv2d, BlurMaxPool2d
-from composer.core import Algorithm, Event, Logger, State
-from composer.core.types import Optimizers
+from composer.algorithms.warnings import NoEffectWarning
+from composer.core import Algorithm, Event, State
+from composer.loggers import Logger
 from composer.utils import module_surgery
 
 log = logging.getLogger(__name__)
@@ -21,7 +24,7 @@ def apply_blurpool(model: torch.nn.Module,
                    replace_convs: bool = True,
                    replace_maxpools: bool = True,
                    blur_first: bool = True,
-                   optimizers: Optional[Optimizers] = None) -> torch.nn.Module:
+                   optimizers: Optional[Union[Optimizer, Sequence[Optimizer]]] = None) -> torch.nn.Module:
     """Add anti-aliasing filters to the strided :class:`torch.nn.Conv2d` and/or :class:`torch.nn.MaxPool2d` modules
     within `model`.
 
@@ -40,8 +43,8 @@ def apply_blurpool(model: torch.nn.Module,
             overhead (though more closely matching
             `the paper <http://proceedings.mlr.press/v97/zhang19a.html>`_).
             See :class:`.BlurConv2d` for further discussion. Default: ``True``.
-        optimizers (Optimizers, optional):  Existing optimizers bound to
-            ``model.parameters()``. All optimizers that have already been
+        optimizers (torch.optim.Optimizer | Sequence[torch.optim.Optimizer], optional):
+            Existing optimizers bound to ``model.parameters()``. All optimizers that have already been
             constructed with ``model.parameters()`` must be specified here so
             they will optimize the correct parameters.
 
@@ -144,7 +147,7 @@ class BlurPool(Algorithm):
                  f'Model now has {num_blurpool_layers} BlurMaxPool2d '
                  f'and {num_blurconv_layers} BlurConv2D layers.')
 
-        logger.metric_fit({
+        logger.data_fit({
             'blurpool/num_blurpool_layers': num_blurpool_layers,
             'blurpool/num_blurconv_layers': num_blurconv_layers,
         })
@@ -153,6 +156,10 @@ class BlurPool(Algorithm):
 def _log_surgery_result(model: torch.nn.Module):
     num_blurpool_layers = module_surgery.count_module_instances(model, BlurMaxPool2d)
     num_blurconv_layers = module_surgery.count_module_instances(model, BlurConv2d)
+    if num_blurconv_layers == 0 and num_blurpool_layers == 0:
+        warnings.warn(
+            NoEffectWarning("Applying BlurPool did not change any layers. "
+                            "No strided Conv2d or Pool2d layers were found."))
     log.info(f'Applied BlurPool to model {model.__class__.__name__}. '
              f'Model now has {num_blurpool_layers} BlurMaxPool2d '
              f'and {num_blurconv_layers} BlurConv2D layers.')
