@@ -7,7 +7,8 @@ from typing import Optional
 
 import torch
 
-from composer.core.types import Algorithm, Event, Logger, State
+from composer.core import Algorithm, Event, State
+from composer.loggers import Logger
 
 log = logging.getLogger(__name__)
 
