@@ -3,12 +3,13 @@
 from __future__ import annotations
 
 import logging
-from typing import Optional
+from typing import Optional, Sequence, Union
 
 import torch
+from torch.optim import Optimizer
 
-from composer.core import Algorithm, Event, Logger, State
-from composer.core.types import Optimizers
+from composer.core import Algorithm, Event, State
+from composer.loggers import Logger
 from composer.utils import module_surgery
 
 log = logging.getLogger(__name__)
@@ -18,7 +19,7 @@ def apply_squeeze_excite(
     model: torch.nn.Module,
     latent_channels: float = 64,
     min_channels: int = 128,
-    optimizers: Optional[Optimizers] = None,
+    optimizers: Optional[Union[Optimizer, Sequence[Optimizer]]] = None,
 ):
     """Adds Squeeze-and-Excitation blocks (`Hu et al, 2019 <https://arxiv.org/abs/1709.01507>`_) after
     :class:`~torch.nn.Conv2d` layers.
@@ -39,10 +40,10 @@ def apply_squeeze_excite(
         min_channels (int, optional): An SE block is added after a :class:`~torch.nn.Conv2d`
             module ``conv`` only if one of the layer's input or output channels is greater than
             this threshold. Default: ``128``.
-        optimizers (Optimizers, optional):  Existing optimizers bound to ``model.parameters()``.
-            All optimizers that have already been constructed with
-            ``model.parameters()`` must be specified here so they will optimize
-            the correct parameters.
+        optimizers (torch.optim.Optimizer | Sequence[torch.optim.Optimizer], optional):
+            Existing optimizers bound to ``model.parameters()``. All optimizers that have already been
+            constructed with ``model.parameters()`` must be specified here so
+            they will optimize the correct parameters.
 
             If the optimizer(s) are constructed *after* calling this function,
             then it is safe to omit this parameter. These optimizers will see the correct
@@ -178,6 +179,6 @@ class SqueezeExcite(Algorithm):
                  f'min_channels={self.min_channels}. '
                  f'Model now has {layer_count} SqueezeExcite layers.')
 
-        logger.metric_fit({
+        logger.data_fit({
             'squeeze_excite/num_squeeze_excite_layers': layer_count,
         })
