@@ -6,20 +6,17 @@ Each callback inherits from the :class:`~composer.core.callback.Callback` base c
 examples for writing your own callbacks at the :class:`~composer.core.callback.Callback` base class.
 """
 from composer.callbacks.callback_hparams import (CallbackHparams, CheckpointSaverHparams, GradMonitorHparams,
-                                                 LRMonitorHparams, MemoryMonitorHparams, RunDirectoryUploaderHparams,
-                                                 SpeedMonitorHparams)
+                                                 LRMonitorHparams, MemoryMonitorHparams, SpeedMonitorHparams)
 from composer.callbacks.checkpoint_saver import CheckpointSaver
 from composer.callbacks.grad_monitor import GradMonitor
 from composer.callbacks.lr_monitor import LRMonitor
 from composer.callbacks.memory_monitor import MemoryMonitor
-from composer.callbacks.run_directory_uploader import RunDirectoryUploader
 from composer.callbacks.speed_monitor import SpeedMonitor
 
 __all__ = [
     "GradMonitor",
     "LRMonitor",
     "MemoryMonitor",
-    "RunDirectoryUploader",
     "SpeedMonitor",
     "CheckpointSaver",
     # hparams objects
@@ -28,6 +25,5 @@ __all__ = [
     "GradMonitorHparams",
     "LRMonitorHparams",
     "MemoryMonitorHparams",
-    "RunDirectoryUploaderHparams",
     "SpeedMonitorHparams",
 ]
