@@ -14,10 +14,9 @@ from composer.core.engine import Engine as Engine
 from composer.core.engine import Trace as Trace
 from composer.core.evaluator import Evaluator as Evaluator
 from composer.core.event import Event as Event
-from composer.core.logging import Logger as Logger
+from composer.core.precision import Precision as Precision
 from composer.core.state import State as State
 from composer.core.time import Time as Time
 from composer.core.time import Timer as Timer
 from composer.core.time import Timestamp as Timestamp
 from composer.core.time import TimeUnit as TimeUnit
-from composer.core.types import Evaluator as Evaluator
