@@ -4,10 +4,7 @@
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from composer.core.types import StateDict
+from typing import Any, Dict
 
 __all__ = ["Serializable"]
 
@@ -15,20 +12,20 @@ __all__ = ["Serializable"]
 class Serializable:
     """Interface for serialization; used by checkpointing."""
 
-    def state_dict(self) -> StateDict:
+    def state_dict(self) -> Dict[str, Any]:
         """Returns a dictionary representing the internal state.
 
         The returned dictionary must be pickale-able via :func:`torch.save`.
 
         Returns:
-            StateDict: The state of the object
+            Dict[str, Any]: The state of the object.
         """
         return {}
 
-    def load_state_dict(self, state: StateDict) -> None:
+    def load_state_dict(self, state: Dict[str, Any]) -> None:
         """Restores the state of the object.
 
         Args:
-            state (StateDict): The state of the object, as previously returned by :meth:`.state_dict`
+            state (Dict[str, Any]): The state of the object, as previously returned by :meth:`.state_dict`.
         """
         pass
