@@ -4,33 +4,29 @@
 
 from __future__ import annotations
 
-import datetime
 import os
+import pathlib
+import re
 import sys
 import textwrap
 import warnings
 from typing import Any, Dict, Optional
 
-from composer.core.logging import LoggerCallback, LogLevel, TLogData
-from composer.core.time import Timestamp
-from composer.core.types import Logger, State, StateDict
-from composer.utils import dist, run_directory
+from composer.core.state import State
+from composer.loggers.logger import Logger, LogLevel
+from composer.loggers.logger_destination import LoggerDestination
+from composer.utils import dist
+from composer.utils.import_helpers import MissingConditionalImportError
 
 __all__ = ["WandBLogger"]
 
 
-class WandBLogger(LoggerCallback):
+class WandBLogger(LoggerDestination):
     """Log to Weights and Biases (https://wandb.ai/)
 
     Args:
         log_artifacts (bool, optional): Whether to log
             `artifacts <https://docs.wandb.ai/ref/python/artifact>`_ (Default: ``False``).
-        log_artifacts_every_n_batches (int, optional): Interval at which to upload
-            `artifacts <https://docs.wandb.ai/ref/python/artifact>`_ to wandb from the
-            :mod:`~.composer.utils.run_directory`. Logging very frequently (e.g. on every
-            batch) can substantially slow down training, so we recommend doing so
-            infrequently. Only applicable when ``log_artifacts`` is True (default:
-            ``100``).
         rank_zero_only (bool, optional): Whether to log only on the rank-zero process.
             When logging `artifacts <https://docs.wandb.ai/ref/python/artifact>`_, it is
             highly recommended to log on all ranks.  Artifacts from ranks ≥1 will not be
@@ -44,16 +40,15 @@ class WandBLogger(LoggerCallback):
 
     def __init__(self,
                  log_artifacts: bool = False,
-                 log_artifacts_every_n_batches: int = 100,
                  rank_zero_only: bool = True,
                  init_params: Optional[Dict[str, Any]] = None) -> None:
         try:
             import wandb
         except ImportError as e:
-            raise ImportError(
-                textwrap.dedent("""\
-                Composer was installed without WandB support. To use WandB with Composer, run `pip install mosaicml[wandb]`
-                if using pip or `conda install -c conda-forge wandb` if using Anaconda.""")) from e
+            raise MissingConditionalImportError(extra_deps_group="wandb",
+                                                conda_package="wandb",
+                                                conda_channel="conda-forge") from e
+
         del wandb  # unused
         if log_artifacts and rank_zero_only:
             warnings.warn(
@@ -64,19 +59,17 @@ class WandBLogger(LoggerCallback):
         self._enabled = (not rank_zero_only) or dist.get_global_rank() == 0
 
         self._log_artifacts = log_artifacts
-        self._log_artifacts_every_n_batches = log_artifacts_every_n_batches
-        self._last_upload_timestamp = datetime.datetime.fromtimestamp(0)
         if init_params is None:
             init_params = {}
         self._init_params = init_params
 
-    def log_metric(self, timestamp: Timestamp, log_level: LogLevel, data: TLogData):
+    def log_data(self, state: State, log_level: LogLevel, data: Dict[str, Any]):
         import wandb
         del log_level  # unused
         if self._enabled:
-            wandb.log(data, step=int(timestamp.batch))
+            wandb.log(data, step=int(state.timer.batch))
 
-    def state_dict(self) -> StateDict:
+    def state_dict(self) -> Dict[str, Any]:
         import wandb
 
         # Storing these fields in the state dict to support run resuming in the future.
@@ -95,40 +88,31 @@ class WandBLogger(LoggerCallback):
 
     def init(self, state: State, logger: Logger) -> None:
         import wandb
-        del state, logger  # unused
+        del state  # unused
+        if "name" not in self._init_params:
+            # Use the logger run name if the name is not set.
+            self._init_params["name"] = logger.run_name
+
         if self._enabled:
             wandb.init(**self._init_params)
 
-    def batch_end(self, state: State, logger: Logger) -> None:
-        del logger  # unused
-        if self._enabled and self._log_artifacts and int(
-                state.timer.batch_in_epoch) % self._log_artifacts_every_n_batches == 0:
-            self._upload_artifacts()
+    def log_file_artifact(self, state: State, log_level: LogLevel, artifact_name: str, file_path: pathlib.Path, *,
+                          overwrite: bool):
+        del state, log_level, overwrite  # unused
+
+        # replace all unsupported characters with periods
+        # Only alpha-numeric, periods, hyphens, and underscores are supported by wandb.
+        new_artifact_name = re.sub(r'[^a-zA-Z0-9-_\.]', '.', artifact_name)
+        if new_artifact_name != artifact_name:
+            warnings.warn(("WandB permits only alpha-numeric, periods, hyphens, and underscores in artifact names. "
+                           f"The artifact with name '{artifact_name}' will be stored as '{new_artifact_name}'."))
 
-    def epoch_end(self, state: State, logger: Logger) -> None:
-        del state, logger  # unused
         if self._enabled and self._log_artifacts:
-            self._upload_artifacts()
-
-    def _upload_artifacts(self):
-        import wandb
-
-        # Scan the run directory and upload artifacts to wandb
-        # On resnet50, _log_artifacts() caused a 22% throughput degradation
-        # wandb.log_artifact() is async according to the docs
-        # (see https://docs.wandb.ai/guides/artifacts/api#2.-create-an-artifact)
-        # so uploads will not block the training loop
-        # slowdown is likely from extra I/O of scanning the directory and/or
-        # scheduling uploads
-        modified_files = run_directory.get_modified_files(self._last_upload_timestamp)
-        for modified_file in modified_files:
-            file_type = modified_file.split(".")[-1]
-            relpath = os.path.relpath(modified_file, run_directory.get_run_directory())
-            relpath = f"rank_{dist.get_global_rank()}-" + relpath.replace("/", "-")
-            artifact = wandb.Artifact(name=relpath, type=file_type)
-            artifact.add_file(os.path.abspath(modified_file))
+            import wandb
+            extension = file_path.name.split(".")[-1]
+            artifact = wandb.Artifact(name=new_artifact_name, type=extension)
+            artifact.add_file(os.path.abspath(file_path))
             wandb.log_artifact(artifact)
-        self._last_upload_timestamp = run_directory.get_run_directory_timestamp()
 
     def post_close(self) -> None:
         import wandb
@@ -137,9 +121,6 @@ class WandBLogger(LoggerCallback):
         if not self._enabled:
             return
 
-        if self._log_artifacts:
-            self._upload_artifacts()
-
         exc_tpe, exc_info, tb = sys.exc_info()
 
         if (exc_tpe, exc_info, tb) == (None, None, None):
