@@ -1,8 +1,17 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""The GPT-2 model family is set of transformer-based networks for autoregressive language modeling at various scales.
+This family was originally proposed by OpenAI, and is trained on the OpenWebText dataset. It is useful for downstream
+language generation tasks, such as summarization, translation, and dialog.
+
+See the :doc:`Model Card </model_cards/GPT2>` for more details.
+"""
+
 from composer.models.gpt2.gpt2_hparams import GPT2Hparams as GPT2Hparams
 from composer.models.gpt2.model import GPT2Model as GPT2Model
 
+__all__ = ["GPT2Model", "GPT2Hparams"]
+
 _metadata = {
     'gpt2': {
         '_task': 'Language Modeling',
@@ -31,4 +40,4 @@ _metadata = {
         '_ttt': '08:25',
         '_hparams': 'gpt2_125m.yaml'
     }
-}
\ No newline at end of file
+}
