@@ -1,5 +1,17 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""The ResNet model family is a set of convolutional neural networks described in `Deep Residual Learning for Image
+Recognition <https://arxiv.org/abs/1512.03385>`_ (He et al, 2015). ResNets can be used as the base for a variety of
+vision tasks. ImageNet ResNets are a subset of the ResNet family which were designed specifically for classification on
+the ImageNet dataset.
+
+See the :doc:`Model Card </model_cards/resnet>` for more details.
+"""
+from composer.models.resnet.model import ComposerResNet as ComposerResNet
+from composer.models.resnet.resnet_hparams import ResNetHparams as ResNetHparams
+
+__all__ = ["ComposerResNet", "ResNetHparams"]
+
 _metadata = {
     'resnet18': {
         '_task': 'Image Classification',
