@@ -10,6 +10,7 @@ import yahp as hp
 
 from composer.models.model_hparams import ModelHparams
 from composer.models.timm.model import Timm
+from composer.utils.import_helpers import MissingConditionalImportError
 
 __all__ = ["TimmHparams"]
 
@@ -52,10 +53,7 @@ class TimmHparams(ModelHparams):
             try:
                 import timm
             except ImportError as e:
-                raise ImportError(
-                    textwrap.dedent("""\
-                    Composer was installed without timm support. To use timm with Composer, run `pip install mosaicml[timm]`
-                    if using pip or `pip install timm>=0.5.4` if using Anaconda.""")) from e
+                raise MissingConditionalImportError(extra_deps_group="timm", conda_package="timm >=0.5.4") from e
             raise ValueError(f"model must be one of {timm.models.list_models()}")
 
     def initialize_object(self):
