@@ -3,18 +3,21 @@
 """The base :class:`~composer.trainer.devices.device.Device` class."""
 
 from abc import ABC, abstractmethod
+from collections.abc import Mapping, Sequence
 from contextlib import contextmanager
-from typing import Generator, TypeVar, Union, cast
+from typing import Any, Callable, Generator, TypeVar, Union
 
+import torch
 import torch.nn
+from torch.optim import Optimizer
 
+from composer.core.precision import Precision
 from composer.core.serializable import Serializable
-from composer.core.types import Batch, BatchPair, Optimizer, Precision, Tensor
-from composer.utils.iter_helpers import map_collection
 
 __all__ = ["Device", "T_nnModule"]
 
 T_nnModule = TypeVar("T_nnModule", bound=torch.nn.Module)
+T_Batch = TypeVar('T_Batch')
 
 
 class Device(Serializable, ABC):
@@ -42,7 +45,7 @@ class Device(Serializable, ABC):
         pass
 
     @abstractmethod
-    def tensor_to_device(self, tensor: Tensor) -> Tensor:
+    def tensor_to_device(self, tensor: torch.Tensor) -> torch.Tensor:
         """Invoked by the :class:`.Trainer` to move a tensor onto a device.
 
         Args:
@@ -53,22 +56,24 @@ class Device(Serializable, ABC):
         """
         pass
 
-    def batch_to_device(self, batch: Batch) -> Batch:
-        """Invoked by the :class:`.Trainer` to move the ``batch`` onto the device.
+    def batch_to_device(self, batch: T_Batch) -> T_Batch:
+        """Invoked by the :class:`.Trainer` move all tensors items in a batch to device. Supports nested sequences and
+        mappings of tensors. Ignores non-tensor items. Preserves sequence and types when possible, otherwise converts
+        sequences to lists. Converts mappings to dictionaries.
 
         Args:
-            batch (Batch): The batch to move to the device.
+            batch (Any): The batch to move to the device.
 
         Returns:
             Batch: The batch on the device.
         """
-        if isinstance(batch, Tensor):
-            return self.tensor_to_device(batch)
-        if isinstance(batch, (tuple, list)):  # BatchPair
-            return cast(BatchPair, type(batch)(map_collection(x, self.tensor_to_device) for x in batch))
-        if isinstance(batch, dict):  # BatchDict
-            return {k: self.tensor_to_device(v) for k, v in batch.items()}
-        raise TypeError(f"Unsupported type for batch: {type(batch)}")
+
+        def _to_device(x):
+            if isinstance(x, torch.Tensor):
+                return self.tensor_to_device(x)
+            return x
+
+        return _map_batch(batch, _to_device)
 
     def optimizer_to_device(self, optimizer: Optimizer) -> Optimizer:
         """Invoked by the :class:`.Trainer` to move the optimizer's state onto the device.
@@ -81,7 +86,7 @@ class Device(Serializable, ABC):
         """
         for state in optimizer.state.values():
             for k, v in state.items():
-                if isinstance(v, Tensor):
+                if isinstance(v, torch.Tensor):
                     state[k] = self.tensor_to_device(v)
         return optimizer
 
@@ -94,7 +99,7 @@ class Device(Serializable, ABC):
 
         .. doctest::
 
-            >>> from composer.core.types import Precision
+            >>> from composer.core.precision import Precision
             >>> from composer.trainer.devices import DeviceCPU
             >>>
             >>> device = DeviceCPU()
@@ -113,3 +118,25 @@ class Device(Serializable, ABC):
             Generator[None, None, None]: A context for the precision.
         """
         pass
+
+
+def _map_batch(batch: Any, map_fn: Callable) -> Any:
+    """Recursively maps a function to all items in a batch.
+
+    Args:
+        batch: Nested lists and dictionaries.
+        map_fn: A function to invoke on each element.
+
+    Returns:
+        Collections: The result of applying ``map_fn`` on each element of the ``batch``.
+        The type of ``batch`` is preserved.
+    """
+    if isinstance(batch, Mapping):
+        return {k: _map_batch(v, map_fn) for k, v in batch.items()}
+
+    if isinstance(batch, Sequence) and not isinstance(batch, (str, bytes)):
+        try:
+            return type(batch)(_map_batch(x, map_fn) for x in batch)  # type: ignore
+        except TypeError:
+            return [_map_batch(x, map_fn) for x in batch]
+    return map_fn(batch)
