@@ -1,5 +1,7 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""The :class:`~yahp.hparams.Hparams` used to construct devices."""
+
 from __future__ import annotations
 
 from abc import abstractmethod
@@ -11,9 +13,12 @@ from composer.trainer.devices.device import Device
 from composer.trainer.devices.device_cpu import DeviceCPU
 from composer.trainer.devices.device_gpu import DeviceGPU
 
+__all__ = ["DeviceHparams", "CPUDeviceHparams", "GPUDeviceHparams"]
+
 
 @dataclass
 class DeviceHparams(hp.Hparams):
+    """Base for :class:`.CPUDeviceHparams` and :class:`.GPUDeviceHparams`"""
 
     @abstractmethod
     def initialize_object(self) -> Device:
@@ -22,15 +27,15 @@ class DeviceHparams(hp.Hparams):
 
 @dataclass
 class GPUDeviceHparams(DeviceHparams):
-    prefetch_in_cuda_stream: bool = hp.optional(doc="Whether to use a separate cuda stream for prefetching",
-                                                default=True)
+    """Used to construct a :class:`.DeviceGPU`"""
 
     def initialize_object(self) -> DeviceGPU:
-        return DeviceGPU(prefetch_in_cuda_stream=self.prefetch_in_cuda_stream)
+        return DeviceGPU()
 
 
 @dataclass
 class CPUDeviceHparams(DeviceHparams):
+    """Used to construct a :class:`.DeviceCPU`"""
 
     def initialize_object(self) -> DeviceCPU:
         return DeviceCPU()
